==> haskell-linear-1.22-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear
version:              1.22
visibility:           public
id:                   linear-1.22-DKKZ1T4bMvg8NrfCIw60jL
key:                  linear-1.22-DKKZ1T4bMvg8NrfCIw60jL
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  36e5276d86e6b2bc6dec61c191908f2d
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.2.8/site-local/linear-1.22
library-dirs:         /usr/lib/ghc-9.2.8/site-local/linear-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.22-DKKZ1T4bMvg8NrfCIw60jL
depends:
    adjunctions-4.4.2-15bIPdZpLfBFeEAyb75tkK base-4.16.4.0
    base-orphans-0.8.8.2-JlIWhIPeUpvEW7tKkRHKfV binary-0.8.9.0
    bytes-0.17.4-I8yB25FGUw6IX97t6KNBxC
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22 containers-0.6.5.1
    deepseq-1.4.6.1 distributive-0.6.2.1-83AMicm4Fuv4z0luD6O5UC
    ghc-prim-0.8.0 hashable-1.4.4.0-1DKi0WUbpLrE22bUerprT9
    indexed-traversable-0.1.4-7eXGkThldZqIiMZcmRdgw5
    lens-5.2.3-7KIPe29YDsM72AVahiJlyf
    random-1.2.1.2-A1nmgsccnvnI4hMd5jmfsN
    reflection-2.1.8-3F2ckADzC36G5quo3zF39s
    semigroupoids-5.3.7-DRrQ6HM3i3lBidmriDf0rx
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-EKpOBluUqpuDOTuVUTImll
    vector-0.13.1.0-6G7HaD4XqvmDrN5OhcYDtS
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-1.22-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear
version:              1.22
visibility:           public
id:                   linear-1.22-1zrgmAfLpqFC76yetZVXNl
key:                  linear-1.22-1zrgmAfLpqFC76yetZVXNl
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  b16d5f1a91bf82f983fae6a3af9dbae7
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.2.8/site-local/linear-1.22
library-dirs:         /usr/lib/ghc-9.2.8/site-local/linear-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.22-1zrgmAfLpqFC76yetZVXNl
depends:
    adjunctions-4.4.2-J6TeXmEqDpA25KuuvGaVOQ base-4.16.4.0
    base-orphans-0.8.8.2-JCprvzeFckGBMb9RgofvxL binary-0.8.9.0
    bytes-0.17.4-E6Hq64ll9ek83daaHvv5rp
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22 containers-0.6.5.1
    deepseq-1.4.6.1 distributive-0.6.2.1-9No2204dclP3UCFixPIren
    ghc-prim-0.8.0 hashable-1.4.4.0-JynHLbpSPE72B4j6uWctY4
    indexed-traversable-0.1.4-35fjUdFZagCEp0xuuMh8XU
    lens-5.2.3-FaAjdvRjDs8BQhMYQYzR8W
    random-1.2.1.2-5cse3egicJy98i0Qegn8w0
    reflection-2.1.8-VJTcUTuLn84d0iM40mhD3
    semigroupoids-5.3.7-CVlhZfzuWqLLDIZXfRThIz
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP template-haskell-2.18.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-AzoOiKjV26Z32LkoSmNfI7
    vector-0.13.1.0-JX40x5KeA95953did9SvPW
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
